@@ -211,6 +211,8 @@ int32_t SPVM__TestCase__NativeAPI__check_native_api_indexes(SPVM_ENV* env, SPVM_
   if ((void*)&env->set_command_info_program_name!= &env_array[193]) { stack[0].ival = 0; return 0;}
   if ((void*)&env->set_command_info_argv!= &env_array[194]) { stack[0].ival = 0; return 0;}
   if ((void*)&env->get_class_id_by_name!= &env_array[195]) { stack[0].ival = 0; return 0;}
+  if ((void*)&env->strerror!= &env_array[196]) { stack[0].ival = 0; return 0;}
+  if ((void*)&env->new_string_array!= &env_array[197]) { stack[0].ival = 0; return 0;}
 
   stack[0].ival = 1;
 
@@ -2630,3 +2632,86 @@ int32_t SPVM__TestCase__NativeAPI__strerror_value(SPVM_ENV* env, SPVM_VALUE* sta
   
   return 0;
 }
+
+int32_t SPVM__TestCase__NativeAPI__new_object_array_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  void* obj_object_array = env->new_object_array_raw(env, stack, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, 2);
+  
+  if (!(env->is_type(env, stack, obj_object_array, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, 1))) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  if (!(env->get_ref_count(env, stack, obj_object_array) == 0)) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  if (!(env->length(env, stack, obj_object_array) == 2)) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  // Free
+  env->inc_ref_count(env, stack, obj_object_array);
+  env->dec_ref_count(env, stack, obj_object_array);
+  
+  stack[0].ival = 1;
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__new_object_array(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  void* obj_object_array = env->new_object_array(env, stack, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, 2);
+  
+  if (!(env->is_type(env, stack, obj_object_array, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, 1))) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  if (!(env->get_ref_count(env, stack, obj_object_array) == 1)) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  if (!(env->length(env, stack, obj_object_array) == 2)) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  stack[0].ival = 1;
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__new_string_array(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  void* obj_string_array = env->new_string_array(env, stack, 2);
+  
+  if (!(env->is_type(env, stack, obj_string_array, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, 1))) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  if (!(env->get_ref_count(env, stack, obj_string_array) == 1)) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  if (!(env->length(env, stack, obj_string_array) == 2)) {
+    stack[0].ival = 0;
+    return 0;
+  }
+  
+  stack[0].ival = 1;
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__new_string_array_value(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  void* obj_string_array = env->new_string_array(env, stack, 2);
+  env->set_elem_object(env, stack, obj_string_array, 0, env->new_string_nolen(env, stack, "abc"));
+  env->set_elem_object(env, stack, obj_string_array, 1, env->new_string_nolen(env, stack, "def"));
+  
+  stack[0].oval = obj_string_array;
+  return 0;
+}
